==> aliyun-python-sdk-swas-open-1.0.1.tar.gz: aliyun-python-sdk-swas-open-1.0.1/aliyunsdkswas_open/request/v20200601/ListCustomImagesRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest

class ListCustomImagesRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'SWAS-OPEN', '2020-06-01', 'ListCustomImages','SWAS-OPEN')
		self.set_method('POST')

	def get_SystemSnapshotId(self): # String
		return self.get_query_params().get('SystemSnapshotId')

	def set_SystemSnapshotId(self, SystemSnapshotId):  # String
		self.add_query_param('SystemSnapshotId', SystemSnapshotId)
	def get_DataSnapshotId(self): # String
		return self.get_query_params().get('DataSnapshotId')

	def set_DataSnapshotId(self, DataSnapshotId):  # String
		self.add_query_param('DataSnapshotId', DataSnapshotId)
	def get_ClientToken(self): # String
		return self.get_query_params().get('ClientToken')

	def set_ClientToken(self, ClientToken):  # String
		self.add_query_param('ClientToken', ClientToken)
	def get_ImageNames(self): # String
		return self.get_query_params().get('ImageNames')

	def set_ImageNames(self, ImageNames):  # String
		self.add_query_param('ImageNames', ImageNames)
	def get_PageNumber(self): # Integer
		return self.get_query_params().get('PageNumber')

	def set_PageNumber(self, PageNumber):  # Integer
		self.add_query_param('PageNumber', PageNumber)
	def get_PageSize(self): # Integer
		return self.get_query_params().get('PageSize')

	def set_PageSize(self, PageSize):  # Integer
		self.add_query_param('PageSize', PageSize)
	def get_ImageIds(self): # String
		return self.get_query_params().get('ImageIds')

	def set_ImageIds(self, ImageIds):  # String
		self.add_query_param('ImageIds', ImageIds)

==> aliyun-python-sdk-swas-open-1.0.6.tar.gz: aliyun-python-sdk-swas-open-1.0.6/aliyunsdkswas_open/request/v20200601/ListCustomImagesRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest

class ListCustomImagesRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'SWAS-OPEN', '2020-06-01', 'ListCustomImages','SWAS-OPEN')
		self.set_method('POST')

	def get_SystemSnapshotId(self): # String
		return self.get_query_params().get('SystemSnapshotId')

	def set_SystemSnapshotId(self, SystemSnapshotId):  # String
		self.add_query_param('SystemSnapshotId', SystemSnapshotId)
	def get_DataSnapshotId(self): # String
		return self.get_query_params().get('DataSnapshotId')

	def set_DataSnapshotId(self, DataSnapshotId):  # String
		self.add_query_param('DataSnapshotId', DataSnapshotId)
	def get_ClientToken(self): # String
		return self.get_query_params().get('ClientToken')

	def set_ClientToken(self, ClientToken):  # String
		self.add_query_param('ClientToken', ClientToken)
	def get_ImageNames(self): # String
		return self.get_query_params().get('ImageNames')

	def set_ImageNames(self, ImageNames):  # String
		self.add_query_param('ImageNames', ImageNames)
	def get_PageNumber(self): # Integer
		return self.get_query_params().get('PageNumber')

	def set_PageNumber(self, PageNumber):  # Integer
		self.add_query_param('PageNumber', PageNumber)
	def get_ResourceGroupId(self): # String
		return self.get_query_params().get('ResourceGroupId')

	def set_ResourceGroupId(self, ResourceGroupId):  # String
		self.add_query_param('ResourceGroupId', ResourceGroupId)
	def get_PageSize(self): # Integer
		return self.get_query_params().get('PageSize')

	def set_PageSize(self, PageSize):  # Integer
		self.add_query_param('PageSize', PageSize)
	def get_Tags(self): # RepeatList
		return self.get_query_params().get('Tag')

	def set_Tags(self, Tag):  # RepeatList
		for depth1 in range(len(Tag)):
			if Tag[depth1].get('Key') is not None:
				self.add_query_param('Tag.' + str(depth1 + 1) + '.Key', Tag[depth1].get('Key'))
			if Tag[depth1].get('Value') is not None:
				self.add_query_param('Tag.' + str(depth1 + 1) + '.Value', Tag[depth1].get('Value'))
	def get_ImageIds(self): # String
		return self.get_query_params().get('ImageIds')

	def set_ImageIds(self, ImageIds):  # String
		self.add_query_param('ImageIds', ImageIds)
